@@ -9,7 +9,9 @@ class IDrone(IRobot, abc.ABC):
     Define all actions needed for flying a drone and declare the get_input() abstract method
     """
     def __init__(self):
-        super().__init__()
+        print('Start IDrone')
+        super(IDrone).__init__()
+
         self.basic_time_step = int(self.getBasicTimeStep())
         self.name = self.getName()
         self._set_constants()
