@@ -2,12 +2,13 @@ import abc
 from controller import Robot
 
 
-class IRobot(Robot):
+class IRobot(Robot, abc.ABC):
     """
     Inherit functionalities provided by the Webots Robot library and declare abstract methods
     """
     def __init__(self):
-        super(IRobot).__init__()
+        print('Start IRobot')
+        super().__init__()
 
     @abc.abstractmethod
     def initialize(self):
