@@ -8,9 +8,10 @@ from flockai.webots_controllers.flockai_controller import FlockAIController
 from controller import InertialUnit, Camera, LED, Emitter, Receiver, GPS, Compass, Gyro, Motor
 
 
-class KeyboardMavic2DJI(FlockAIController, KeyboardControlledDrone):
+class KeyboardMavic2DJI(KeyboardControlledDrone):
     def __init__(self):
-        super(KeyboardMavic2DJI, self).__init__()
+        print('Start KeyboardMavic')
+        super(KeyboardMavic2DJI).__init__()
         self.initialize()
 
     def initialize(self):
